@@ -1354,7 +1354,8 @@ public final class DBCassandraAstyanaxImpl implements DatabookStore {
 			toReturn.setKey(commentId);
 			toReturn.setText(columns.getColumnByName("Text").getStringValue());
 			toReturn.setFullName(columns.getColumnByName("FullName").getStringValue());
-			toReturn.setEdit(columns.getColumnByName("IsEdited").getBooleanValue());
+			if(columns.getColumnByName("IsEdited") != null)
+				toReturn.setEdit(columns.getColumnByName("IsEdited").getBooleanValue());
 			toReturn.setFeedid(columns.getColumnByName("Feedid").getStringValue());
 			toReturn.setUserid(columns.getColumnByName("Userid").getStringValue());
 			toReturn.setTime(getDateFromTimeInMillis(columns.getColumnByName("Timestamp").getStringValue()));
@@ -1363,7 +1364,7 @@ public final class DBCassandraAstyanaxImpl implements DatabookStore {
 				toReturn.setLastEditTime(getDateFromTimeInMillis(columns.getColumnByName("LastEditTime").getStringValue()));
 
 		} catch (ConnectionException e) {
-			e.printStackTrace();
+			_log.debug(e.toString());
 			return null;
 		}	
 		return toReturn;
@@ -2353,7 +2354,7 @@ public final class DBCassandraAstyanaxImpl implements DatabookStore {
 		}
 
 		_log.debug("VRE ids are " + ids);
-		
+
 		return ids;
 
 	}
